@@ -16,9 +16,9 @@ from sklearn.preprocessing import (OneHotEncoder,
 
 import warnings
 
-
 warnings.filterwarnings('ignore')
 
+
 def initial_preprocessor(
         data,
         json_file):
@@ -276,7 +276,7 @@ def generate_column_labels(full_pipeline, numeric_cols, text_cols):
 
             except Exception as error:
                 # For debugging only
-                print(error)
+                (error)
                 cols = list(numeric_cols)
 
         return cols
